|  | Image Name | Type | Status | Visibility | Protected | Format | Size | Actions
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
|  | {$ image.name $} | {$ image | imageType $} | {$ image.status | imageStatus $} | {$ image.filtered_visibility $} | {$ image.protected | yesno $} | {$ image.disk_format | noValue | uppercase $} | {$ image.size | bytes $} |
Visibility {$ image.filtered_visibility $} Protected {$ image.protected | yesno $} Format {$ image.disk_format | noValue | uppercase $} Size {$ image.size | bytes $} Min Disk (GB) {$ image.min_disk | noValue $} Min RAM (MB) {$ image.min_ram | noValue $}